@@ -13,7 +13,7 @@ class AioThing:
         self._current_task = None
 
     def _guard_start(self, fn):
-        async def guarded_fn():
+        async def guarded_fn(*args, **kwargs):
             if self.started:
                 return
             self.started = True
@@ -22,16 +22,16 @@ class AioThing:
                 await aw.start()
             for aw in self.waits:
                 await aw.start_and_wait()
-            self._current_task = asyncio.create_task(fn())
+            self._current_task = asyncio.create_task(fn(*args, **kwargs))
             return self._current_task
         return guarded_fn
 
     def _guard_stop(self, fn):
-        async def guarded_fn():
+        async def guarded_fn(*args, **kwargs):
             if not self.started:
                 return
             self.started = False
-            r = await fn()
+            r = await fn(*args, **kwargs)
             await self.cancel()
             for aw in reversed(self.starts + self.waits):
                 await aw.stop()
